==> huaweicloudsdksts-3.1.137-py2.py3-none-any.whl: huaweicloudsdksts/v1/model/decode_authorization_message_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DecodeAuthorizationMessageResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'decoded_message': 'str'
    }

    attribute_map = {
        'decoded_message': 'decoded_message'
    }

    def __init__(self, decoded_message=None):
        """DecodeAuthorizationMessageResponse

        The model defined in huaweicloud sdk

        :param decoded_message: 鉴权失败原因的明文。
        :type decoded_message: str
        """
        
        super(DecodeAuthorizationMessageResponse, self).__init__()

        self._decoded_message = None
        self.discriminator = None

        if decoded_message is not None:
            self.decoded_message = decoded_message

    @property
    def decoded_message(self):
        """Gets the decoded_message of this DecodeAuthorizationMessageResponse.

        鉴权失败原因的明文。

        :return: The decoded_message of this DecodeAuthorizationMessageResponse.
        :rtype: str
        """
        return self._decoded_message

    @decoded_message.setter
    def decoded_message(self, decoded_message):
        """Sets the decoded_message of this DecodeAuthorizationMessageResponse.

        鉴权失败原因的明文。

        :param decoded_message: The decoded_message of this DecodeAuthorizationMessageResponse.
        :type decoded_message: str
        """
        self._decoded_message = decoded_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DecodeAuthorizationMessageResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdksts-3.1.147-py2.py3-none-any.whl: huaweicloudsdksts/v1/model/decode_authorization_message_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DecodeAuthorizationMessageResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'decoded_message': 'str'
    }

    attribute_map = {
        'decoded_message': 'decoded_message'
    }

    def __init__(self, decoded_message=None):
        r"""DecodeAuthorizationMessageResponse

        The model defined in huaweicloud sdk

        :param decoded_message: 鉴权失败原因的明文。
        :type decoded_message: str
        """
        
        super(DecodeAuthorizationMessageResponse, self).__init__()

        self._decoded_message = None
        self.discriminator = None

        if decoded_message is not None:
            self.decoded_message = decoded_message

    @property
    def decoded_message(self):
        r"""Gets the decoded_message of this DecodeAuthorizationMessageResponse.

        鉴权失败原因的明文。

        :return: The decoded_message of this DecodeAuthorizationMessageResponse.
        :rtype: str
        """
        return self._decoded_message

    @decoded_message.setter
    def decoded_message(self, decoded_message):
        r"""Sets the decoded_message of this DecodeAuthorizationMessageResponse.

        鉴权失败原因的明文。

        :param decoded_message: The decoded_message of this DecodeAuthorizationMessageResponse.
        :type decoded_message: str
        """
        self._decoded_message = decoded_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DecodeAuthorizationMessageResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
